/*
 * file CcStorageLocation.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cc.CcStorageLocation
 *
 * (C) Copyright IBM Corporation 2010, 2011.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

/**
 * <p>
 * A proxy for a ClearCase storage location.
 * A storage location provides a simplified way for users to specify the
 * storage directory for ClearCase VOBs and views without resorting to explicit 
 * pathnames.
 * </p>
 */

public interface CcStorageLocation extends CcResource {

    /**
     * Name of the server hosting the storage location
     */
    PropertyName<String> SERVER_HOST =
        new PropertyName<String>(PROPERTY_NAMESPACE, "stgloc-server-host");

    /**
     * Get the value of this proxy's {@link #SERVER_HOST} property.
     * @return this storage location's server host
     * @throws WvcmException if this proxy doesn't define a value for this property.
     */
    String getServerHost() throws WvcmException;

    /**
     * Type of the storage location
     */
    enum StorageType {
        /** This is a view storage location. */
        VIEW,

        /** This is a VOB storage location. */
        VOB;
    }

    /**
     * The type of storage location
     */
    PropertyName<StorageType> STORAGE_TYPE =
        new PropertyName<StorageType>(PROPERTY_NAMESPACE, "stgloc-storage-type");

    /**
     * Get the value of this proxy's {@link #STORAGE_TYPE} property.
     * @return this storage location's type
     * @throws WvcmException if this proxy doesn't define a value for this property.
     */
    StorageType getStorageType() throws WvcmException;
 
}
